| summary.synMicro_object | R Documentation |
summary method for class "summary.synMicro_object".
## S3 method for class 'synMicro_object'
summary(object, max_print = 4, ...)
object |
|
max_print |
maximum number of synthetic datset to print summaries |
... |
other parameters to be passed through to other functions. |
summary reports the synthesis results for each variable.
summary reports the synthesis results for each variable. It compares the summary statistics of each variable for the original dataset(Orig.) and synthetic datasets(synt.#), their averaging(Q_bar), and between variance(B_m).
multipleSyn
## preparing to generate synthetic datsets
dat_obj <- readData(Y_input = iris[,1:4],
X_input = data.frame(Species = iris[,5]))
mod_obj <- createModel(dat_obj, max_R_S_K=c(30,50,20))
## generating synthetic datasets
res_obj <- multipleSyn(dat_obj, mod_obj, n_burnin = 100, m = 2,
interval_btw_Syn = 50, show_iter = FALSE)
summary(res_obj)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.